from django.contrib.auth.backends import ModelBackend
from django.contrib.auth import get_user_model


class DualAuthentication(ModelBackend):
    """
    This is a ModelBacked that allows authentication
    with either a username or an email address.

    """
    def authenticate(self, username=None, password=None):
        try:
            kwargs = {'username': username}
            user = get_user_model().objects.get(**kwargs)
        except:
            kwargs = {'email': username}
            user = get_user_model().objects.get(**kwargs)
        finally:
            try:
                if user.check_password(password):
                    return user
            except:
                return None

    def get_user(self, username):
        try:
            return get_user_model().objects.get(pk=username)
        except get_user_model().DoesNotExist:
            return None
            


#!/usr/bin/env python

from setuptools import setup


setup(
    name='django-dual-authentication',
    version='0.4.0',
    packages=['django-dual-authentication'],
    license='MIT',
    author='Zeioth',
    author_email='test@gmail.com',
    description='Allows authentication with either a username or an email address.',
    long_description='Allows authentication with either a username or an email address.',
    install_requires='',
    include_package_data=True,
    url='https://github.com/Zeioth/django-dual-authentication',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    ]
)
